@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from pathlib import Path
+from os import PathLike
 
 from blx.cid import CID
 from blx.client import get_client
@@ -10,7 +10,7 @@ from blx.service_exit import ServiceExit
 __all__ = ["upload"]
 
 
-def upload(cid: CID, file: Path, show_progress=True):
+def upload(cid: CID, file: str | PathLike[str], show_progress=True):
     with Progress("Upload", disable=not show_progress) as progress:
         try:
             client = get_client()
